@@ -4,12 +4,12 @@ It is defined here to avoid circular imports
 """
 from pathlib import Path
 
-from webex_assistant_sdk import SkillApplication
+from webex_assistant_sdk.app import SkillApplication
 from webex_assistant_sdk.crypto import load_private_key_from_file
 
 secret = '{{cookiecutter.app_secret}}'
 
-key = load_private_key_from_file(str(Path(__file__).resolve().parent / 'id_rsa'))
+key = load_private_key_from_file(str(Path(__file__).resolve().parent / 'id_rsa.pem'))
 app = SkillApplication(__name__, secret=secret, private_key=key)
 
 
